@@ -120,3 +120,10 @@ CodigoError = generate_error_codes()
 
 class CodigoErrorAcuse(str, Enum):
     exitoso = 'EA00'
+    envio_banxico = 'EQ00'
+    ok = '0'
+
+
+class TipoRespuestaAcuse(str, Enum):
+    sincrona = 'sincrona'
+    asincrona = 'asincrona'
